/***************************************************************************
 $RCSfile$
                             -------------------
    cvs         : $Id: jobview.h 277 2005-08-24 16:52:02Z aquamaniac $
    begin       : Mon Mar 01 2004
    copyright   : (C) 2004 by Martin Preuss
    email       : martin@libchipcard.de

 ***************************************************************************
 *          Please see toplevel file COPYING for license details           *
 ***************************************************************************/



#ifndef KBANKING_JOBVIEW_H
#define KBANKING_JOBVIEW_H

#include "jobview.ui.h"

#include <qwidget.h>


class JobView;
class KBanking;


#include <qbanking/qbjoblist.h>


class JobView: public JobViewUi {
  Q_OBJECT
public:
  JobView(KBanking *kb,
          QWidget* parent=0, const char* name=0, WFlags fl=0);
  ~JobView();

  bool init();
  bool fini();

protected:
  //void resizeEvent(QResizeEvent *e);

private:
  KBanking *_app;
  QBJobListView *_jobList;

public slots:
  void slotQueueUpdated();
  void slotExecute();
  void slotDequeue();
};







#endif /* KBANKING_JOBVIEW_H */



